@@ -548,22 +548,14 @@ sub help_usage ( $self, $invalid_options = undef ) {
 }
 
 sub help_version ($self) {
-    my $format_dist_info = sub ($dist) {
-        my $id = join q[ ], grep {$_} $dist->id->{branch}, $dist->id->{bookmark}, $dist->id->{tags}->@*;
-
-        my $release_distance_sign = $dist->id->{current_release_distance} ? q[+] : q[];
-
-        return "@{[$dist->name]} @{[$dist->version]}$release_distance_sign $id @{[$dist->id->{node}]} @{[$dist->id->{date}]}";
-    };
-
     if ( $ENV->dist ) {
-        say $format_dist_info->( $ENV->dist );
+        say $ENV->dist->version_string;
     }
     else {
         say join q[ ], $ENV->{SCRIPT_NAME}, ( $main::VERSION ? version->new($main::VERSION)->normal : () );
     }
 
-    say $format_dist_info->( $ENV->pcore ) if !$ENV->dist || $ENV->dist->name ne $ENV->pcore->name;
+    say $ENV->pcore->version_string if !$ENV->dist || $ENV->dist->name ne $ENV->pcore->name;
 
     say 'Perl ' . $^V->normal . " $Config{archname}";
 
